[−][src]Crate max7219
A platform agnostic driver to interface with the MAX7219 (LED matrix display driver)
This driver was built using embedded-hal traits.
Structs
| MAX7219 | Handles communication with the MAX7219 chip for segmented displays. Each display can be connected in series with another and controlled via a single connection. The actual connection interface is selected via constructor functions. |
| PinError | Error raised in case there was a PIN interaction error during communication with the MAX7219 chip. |
Enums
| Command | Possible command register values on the display chip. |
| DecodeMode | Decode modes for BCD encoded input. |